@@ -4,16 +4,16 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.033 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common  2.034 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base  2.033 ;
-use IO::Uncompress::Adapter::Lzf  2.033 ;
+use IO::Uncompress::Base  2.034 ;
+use IO::Uncompress::Adapter::Lzf  2.034 ;
 
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzfError);
 
-$VERSION = '2.033';
+$VERSION = '2.034';
 $UnLzfError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -847,7 +847,7 @@ If the C<$z> object is associated with a file or a filehandle, C<fileno>
 will return the underlying file descriptor. Once the C<close> method is
 called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will return
+If the C<$z> object is associated with a buffer, this method will return
 C<undef>.
 
 =head2 close
